@@ -2,11 +2,7 @@
 #' extrapolation of concentrations for the beginning and end of the
 #' interval.
 #'
-#' @param conc Concentration measured
-#' @param time Time of concentration measurement (must be monotonically
-#'   increasing and the same length as the concentration data)
-#' @param interval Numeric vector of two numbers for the start and end
-#'   time of integration
+#' @inheritParams pk.calc.auxc
 #' @param start,end The start and end of the interval (cannot be given
 #'   if \code{interval} is given)
 #' @param clast,clast.obs,clast.pred The last concentration above the
@@ -21,26 +17,41 @@
 #'   \code{\link{interp.extrap.conc.dose}}).  If \code{NULL},
 #'   \code{\link{interp.extrap.conc}} will be used instead (assuming
 #'   that no doses affecting concentrations are in the interval).
-#' @param method The method for integration (either 'lin up/log down' or
-#'   'linear')
-#' @param auc.type The type of AUC to compute.  Choices are 'AUCinf',
-#'   'AUClast', and 'AUCall'.
 #' @param ... Additional arguments passed to \code{pk.calc.auxc} and
 #'   \code{interp.extrap.conc}
-#' @param options List of changes to the default
-#'   \code{\link{PKNCA.options}} for calculations.
-#' @seealso \code{\link{pk.calc.auxc}}, \code{\link{PKNCA.options}},
-#'   \code{\link{interp.extrap.conc.dose}}
+#' @family AUC calculations
+#' @seealso \code{\link{PKNCA.options}}, \code{\link{interp.extrap.conc.dose}}
 #' @export
 pk.calc.aucint <- function(conc, time,
                            interval=NULL, start=NULL, end=NULL,
-                           clast=pk.calc.clast.obs(conc, time), lambda.z=NA,
-                           time.dose=NULL, route="extravascular", duration.dose=0,
+                           clast=pk.calc.clast.obs(conc, time),
+                           lambda.z=NA,
+                           time.dose=NULL,
+                           route="extravascular",
+                           duration.dose=0,
                            method=NULL,
-                           auc.type="AUClast", ...,
+                           auc.type="AUClast",
+                           conc.blq=NULL,
+                           conc.na=NULL,
+                           check=TRUE,
+                           ...,
                            options=list()) {
   # Check inputs
   method <- PKNCA.choose.option(name="auc.method", value=method, options=options)
+  conc.blq <- PKNCA.choose.option(name="conc.blq", value=conc.blq, options=options)
+  conc.na <- PKNCA.choose.option(name="conc.na", value=conc.na, options=options)
+  if (check) {
+    check.conc.time(conc, time)
+    data <-
+      clean.conc.blq(
+        conc, time,
+        conc.blq=conc.blq,
+        conc.na=conc.na,
+        check=FALSE
+      )
+  } else {
+    data <- data.frame(conc, time)
+  }
   if (is.null(interval)) {
     if (is.null(start) | is.null(end)) {
       stop("If interval is not given, start and end must be given.")
@@ -69,16 +80,16 @@ pk.calc.aucint <- function(conc, time,
   }
   missing_times <-
     if (is.infinite(interval[2])) {
-      setdiff(c(interval[1], time.dose), time)
+      setdiff(c(interval[1], time.dose), data$time)
     } else {
-      setdiff(c(interval, time.dose), time)
+      setdiff(c(interval, time.dose), data$time)
     }
   # Handle the potential double-calculation (before/after tlast) with AUCinf
   conc_clast <- NULL
   time_clast <- NULL
   if (auc.type %in% "AUCinf") {
-    tlast <- pk.calc.tlast(conc=conc, time=time)
-    if (clast != pk.calc.clast.obs(conc=conc, time=time) &
+    tlast <- pk.calc.tlast(conc=data$conc, time=data$time)
+    if (clast != pk.calc.clast.obs(conc=data$conc, time=data$time) &
         interval[2] > tlast) {
       # If using clast.pred, we need to doubly calculate at tlast.
       conc_clast <- clast
@@ -89,7 +100,7 @@ pk.calc.aucint <- function(conc, time,
     if (is.null(time.dose)) {
       missing_conc <-
         interp.extrap.conc(
-          conc=conc, time=time,
+          conc=data$conc, time=data$time,
           time.out=missing_times,
           interp.method=method,
           extrap.method=auc.type,
@@ -99,7 +110,7 @@ pk.calc.aucint <- function(conc, time,
     } else {
       missing_conc <-
         interp.extrap.conc.dose(
-          conc=conc, time=time,
+          conc=data$conc, time=data$time,
           time.out=missing_times,
           interp.method=method,
           extrap.method=auc.type,
@@ -112,8 +123,8 @@ pk.calc.aucint <- function(conc, time,
           out.after=FALSE,
           ...)
     }
-    new_data <- data.frame(conc=c(conc, conc_clast, missing_conc),
-                           time=c(time, time_clast, missing_times))
+    new_data <- data.frame(conc=c(data$conc, conc_clast, missing_conc),
+                           time=c(data$time, time_clast, missing_times))
     new_data <- new_data[new_data$time >= interval[1] &
                            new_data$time <= interval[2],]
     new_data <- new_data[order(new_data$time),]
@@ -136,8 +147,8 @@ pk.calc.aucint <- function(conc, time,
       return(NA_real_)
     }
   } else {
-    conc_interp <- conc
-    time_interp <- time
+    conc_interp <- data$conc
+    time_interp <- data$time
   }
   # AUCinf traces an AUClast curve if the interval is finite (because
   # the interval doesn't go to infinity) while AUCall and AUClast trace
@@ -221,7 +232,12 @@ add.interval.col("aucint.last",
                  desc="The area under the concentration time curve in the interval extrapolating from Tlast to infinity with zeros (matching AUClast)",
                  formalsmap=list(conc="conc.group", time="time.group", time.dose=NULL),
                  depends=c())
-PKNCA.set.summary("aucint.last", business.geomean, business.geocv)
+PKNCA.set.summary(
+  name="aucint.last",
+  description="geometric mean and geometric coefficient of variation",
+  point=business.geomean,
+  spread=business.geocv
+)
 
 add.interval.col("aucint.last.dose",
                  FUN="pk.calc.aucint.last",
@@ -229,7 +245,12 @@ add.interval.col("aucint.last.dose",
                  desc="The area under the concentration time curve in the interval extrapolating from Tlast to infinity with zeros (matching AUClast)",
                  formalsmap=list(conc="conc.group", time="time.group", time.dose="time.dose.group"),
                  depends=c())
-PKNCA.set.summary("aucint.last.dose", business.geomean, business.geocv)
+PKNCA.set.summary(
+  name="aucint.last.dose",
+  description="geometric mean and geometric coefficient of variation",
+  point=business.geomean,
+  spread=business.geocv
+)
 
 add.interval.col("aucint.all",
                  FUN="pk.calc.aucint.all",
@@ -237,7 +258,12 @@ add.interval.col("aucint.all",
                  desc="The area under the concentration time curve in the interval extrapolating from Tlast to infinity with the triangle from Tlast to the next point and zero thereafter (matching AUCall)",
                  formalsmap=list(conc="conc.group", time="time.group", time.dose=NULL),
                  depends=c())
-PKNCA.set.summary("aucint.all", business.geomean, business.geocv)
+PKNCA.set.summary(
+  name="aucint.all",
+  description="geometric mean and geometric coefficient of variation",
+  point=business.geomean,
+  spread=business.geocv
+)
 
 add.interval.col("aucint.all.dose",
                  FUN="pk.calc.aucint.all",
@@ -245,7 +271,12 @@ add.interval.col("aucint.all.dose",
                  desc="The area under the concentration time curve in the interval extrapolating from Tlast to infinity with the triangle from Tlast to the next point and zero thereafter (matching AUCall)",
                  formalsmap=list(conc="conc.group", time="time.group", time.dose="time.dose.group"),
                  depends=c())
-PKNCA.set.summary("aucint.all.dose", business.geomean, business.geocv)
+PKNCA.set.summary(
+  name="aucint.all.dose",
+  description="geometric mean and geometric coefficient of variation",
+  point=business.geomean,
+  spread=business.geocv
+)
 
 add.interval.col("aucint.inf.obs",
                  FUN="pk.calc.aucint.inf.obs",
@@ -253,7 +284,12 @@ add.interval.col("aucint.inf.obs",
                  desc="The area under the concentration time curve in the interval extrapolating from Tlast to infinity with zeros (matching AUClast)",
                  formalsmap=list(conc="conc.group", time="time.group", time.dose=NULL),
                  depends=c("lambda.z", "clast.obs"))
-PKNCA.set.summary("aucint.inf.obs", business.geomean, business.geocv)
+PKNCA.set.summary(
+  name="aucint.inf.obs",
+  description="geometric mean and geometric coefficient of variation",
+  point=business.geomean,
+  spread=business.geocv
+)
 
 add.interval.col("aucint.inf.obs.dose",
                  FUN="pk.calc.aucint.inf.obs",
@@ -261,7 +297,11 @@ add.interval.col("aucint.inf.obs.dose",
                  desc="The area under the concentration time curve in the interval extrapolating from Tlast to infinity with zeros (matching AUClast)",
                  formalsmap=list(conc="conc.group", time="time.group", time.dose="time.dose.group"),
                  depends=c("lambda.z", "clast.obs"))
-PKNCA.set.summary("aucint.inf.obs.dose", business.geomean, business.geocv)
+PKNCA.set.summary(
+  name="aucint.inf.obs.dose",
+  description="geometric mean and geometric coefficient of variation",
+  point=business.geomean,
+  spread=business.geocv)
 
 add.interval.col("aucint.inf.pred",
                  FUN="pk.calc.aucint.inf.pred",
@@ -269,7 +309,12 @@ add.interval.col("aucint.inf.pred",
                  desc="The area under the concentration time curve in the interval extrapolating from Tlast to infinity with the triangle from Tlast to the next point and zero thereafter (matching AUCall)",
                  formalsmap=list(conc="conc.group", time="time.group", time.dose=NULL),
                  depends=c("lambda.z", "clast.pred"))
-PKNCA.set.summary("aucint.inf.pred", business.geomean, business.geocv)
+PKNCA.set.summary(
+  name="aucint.inf.pred",
+  description="geometric mean and geometric coefficient of variation",
+  point=business.geomean,
+  spread=business.geocv
+)
 
 add.interval.col("aucint.inf.pred.dose",
                  FUN="pk.calc.aucint.inf.pred",
@@ -277,4 +322,9 @@ add.interval.col("aucint.inf.pred.dose",
                  desc="The area under the concentration time curve in the interval extrapolating from Tlast to infinity with the triangle from Tlast to the next point and zero thereafter (matching AUCall)",
                  formalsmap=list(conc="conc.group", time="time.group", time.dose="time.dose.group"),
                  depends=c("lambda.z", "clast.pred"))
-PKNCA.set.summary("aucint.inf.pred.dose", business.geomean, business.geocv)
+PKNCA.set.summary(
+  name="aucint.inf.pred.dose",
+  description="geometric mean and geometric coefficient of variation",
+  point=business.geomean,
+  spread=business.geocv
+)
