@@ -6,34 +6,34 @@ library(PKNCA)
 library(dplyr, quietly=TRUE)
 
 ## Load the PK concentration data
-d.conc <- datasets::Theoph %>%
+d_conc <- datasets::Theoph %>%
   mutate(Subject=as.numeric(as.character(Subject)))
 ## Generate the dosing data
-d.dose <- d.conc[d.conc$Time == 0,]
-d.dose$Time <- 0
+d_dose <- d_conc[d_conc$Time == 0,]
+d_dose$Time <- 0
 
 ## Create a concentration object specifying the concentration, time, and
 ## subject columns.  (Note that any number of grouping levels is
 ## supported; you are not restricted to just grouping by subject.)
-my.conc <- PKNCAconc(d.conc,
-                     conc~Time|Subject)
+conc_obj <- PKNCAconc(d_conc,
+                      conc~Time|Subject)
 ## Create a dosing object specifying the dose, time, and subject
 ## columns.  (Note that the grouping factors should be the same as or a
 ## subset of the grouping factors for concentration, and the grouping
 ## columns must have the same names between concentration and dose
 ## objects.)
-my.dose <- PKNCAdose(d.dose,
-                     Dose~Time|Subject)
+dose_obj <- PKNCAdose(d_dose,
+                      Dose~Time|Subject)
 ## Combine the concentration and dosing information both to
 ## automatically define the intervals for NCA calculation and provide
 ## doses for calculations requiring dose.
-my.data <- PKNCAdata(my.conc, my.dose)
+data_obj <- PKNCAdata(conc_obj, dose_obj)
 
 ## Calculate the NCA parameters
-my.results <- pk.nca(my.data)
+results_obj <- pk.nca(data_obj)
 
 ## Summarize the results
-summary(my.results)
+summary(results_obj)
 
 ## ------------------------------------------------------------------------
 PKNCA.options()
@@ -79,34 +79,34 @@ PKNCA.options()
 
 ## ----grouping, eval=FALSE------------------------------------------------
 #  ## Generate a faux multi-study, multi-analyte dataset.
-#  d.conc.parent <- d.conc
-#  d.conc.parent$Subject <- as.numeric(as.character(d.conc.parent$Subject))
-#  d.conc.parent$Study <- d.conc.parent$Subject <= 6
-#  d.conc.parent$Analyte <- "Parent"
-#  d.conc.metabolite <- d.conc.parent
-#  d.conc.metabolite$conc <- d.conc.metabolite$conc/2
-#  d.conc.metabolite$Analyte <- "Metabolite"
-#  d.conc.both <- rbind(d.conc.parent, d.conc.metabolite)
-#  d.conc.both <- d.conc.both[with(d.conc.both, order(Study, Subject, Time, Analyte)),]
-#  d.dose.both <- d.conc.both[d.conc.both$Time == 0 & d.conc.both$Analyte %in% "Parent",
+#  d_conc_parent <- d_conc
+#  d_conc_parent$Subject <- as.numeric(as.character(d_conc_parent$Subject))
+#  d_conc_parent$Study <- d_conc_parent$Subject <= 6
+#  d_conc_parent$Analyte <- "Parent"
+#  d_conc_metabolite <- d_conc_parent
+#  d_conc_metabolite$conc <- d_conc_metabolite$conc/2
+#  d_conc_metabolite$Analyte <- "Metabolite"
+#  d_conc_both <- rbind(d_conc_parent, d_conc_metabolite)
+#  d_conc_both <- d_conc_both[with(d_conc_both, order(Study, Subject, Time, Analyte)),]
+#  d_dose_both <- d_conc_both[d_conc_both$Time == 0 & d_conc_both$Analyte %in% "Parent",
 #                             c("Study", "Subject", "Dose", "Time")]
 #  
 #  ## Create a concentration object specifying the concentration, time,
 #  ## study, and subject columns.  (Note that any number of grouping
 #  ## levels is supporting; you are not restricted to this list.)
-#  my.conc <- PKNCAconc(d.conc.both,
-#                       conc~Time|Study+Subject/Analyte)
+#  conc_obj <- PKNCAconc(d_conc_both,
+#                        conc~Time|Study+Subject/Analyte)
 #  ## Create a dosing object specifying the dose, time, study, and
 #  ## subject columns.  (Note that the grouping factors should be a
 #  ## subset of the grouping factors for concentration, and the columns
 #  ## must have the same names between concentration and dose objects.)
-#  my.dose <- PKNCAdose(d.dose.both,
+#  dose_obj <- PKNCAdose(d_dose_both,
 #                       Dose~Time|Study+Subject)
 #  
 #  # Perform and summarize the PK data as previously described
-#  my.data <- PKNCAdata(my.conc, my.dose)
-#  my.results <- pk.nca(my.data)
-#  summary(my.results)
+#  data_obj <- PKNCAdata(conc_obj, dose_obj)
+#  results_obj <- pk.nca(data_obj)
+#  summary(results_obj)
 
 ## ------------------------------------------------------------------------
 intervals <-
@@ -121,29 +121,29 @@ knitr::kable(PKNCA.options()$single.dose.aucs)
 
 ## ------------------------------------------------------------------------
 ## find.tau can work when all doses have the same interval...
-dose.times <- seq(0, 168, by=24)
-print(dose.times)
-PKNCA::find.tau(dose.times)
+dose_times <- seq(0, 168, by=24)
+print(dose_times)
+PKNCA::find.tau(dose_times)
 
 ## or when the doses have mixed intervals (10 and 24 hours).
-dose.times <- sort(c(seq(0, 168, by=24),
+dose_times <- sort(c(seq(0, 168, by=24),
                      seq(10, 178, by=24)))
-print(dose.times)
-PKNCA::find.tau(dose.times)
+print(dose_times)
+PKNCA::find.tau(dose_times)
 
 ## ----eval=FALSE----------------------------------------------------------
-#  my.intervals <-
+#  intervals_manual <-
 #    data.frame(start=0, end=c(24, Inf),
 #               cmax=c(FALSE, TRUE),
 #               tmax=c(FALSE, TRUE),
 #               auclast=TRUE,
 #               aucinf.obs=c(FALSE, TRUE))
-#  my.data <- PKNCAdata(my.conc, my.dose,
-#                       intervals=my.intervals)
+#  data_obj <- PKNCAdata(conc_obj, dose_obj,
+#                        intervals=intervals_manual)
 
 ## ----eval=FALSE----------------------------------------------------------
-#  my.data <- PKNCAdata(my.conc, my.dose)
-#  my.intervals <- my.data$intervals
-#  my.intervals$aucinf.obs[1] <- TRUE
-#  my.data$intervals <- my.intervals
+#  data_obj <- PKNCAdata(conc_obj, dose_obj)
+#  intervals_manual <- data_obj$intervals
+#  intervals_manual$aucinf.obs[1] <- TRUE
+#  data_obj$intervals <- intervals_manual
 
